@@ -2,6 +2,21 @@
  * Miscellaneous routines for Mathomatic.
  *
  * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -124,10 +139,10 @@ get_screen_size()
 
 /*
  * Allocate the needed global expression storage arrays.
- * Each has n_tokens elements.
+ * Each is static and can hold n_tokens elements.
  * n_tokens must not change until Mathomatic terminates.
  *
- * init_mem() is only called once upon Mathomatic startup
+ * init_mem() is called only once upon Mathomatic startup
  * before using the symbolic math engine,
  * and can be undone by calling free_mem() below.
  *
@@ -287,7 +302,7 @@ long	*vp;
 }
 
 /*
- * Erase all equation spaces.
+ * Erase all equation spaces and initialize the global variables.
  * Similar to a restart.
  */
 void
@@ -395,7 +410,7 @@ copy_espace(src, dest)
 int	src, dest;	/* equation space numbers */
 {
 	if (src == dest) {
-		error("Internal error: copy_espace() source and destination the same.");
+/*		error("Internal error: copy_espace() source and destination the same."); */
 		return;
 	}
 	blt(lhs[dest], lhs[src], n_lhs[src] * sizeof(token_type));
@@ -764,6 +779,7 @@ int	en;	/* equation space number the result is in */
 	}
 	free_result_str();
 	result_str = list_equation(en, false);
+	result_en = en;
 	if (gfp == stdout) {
 		return(result_str != NULL);
 	}
@@ -782,6 +798,7 @@ free_result_str()
 		free(result_str);
 		result_str = NULL;
 	}
+	result_en = -1;
 }
 
 /*
