@@ -2,6 +2,21 @@
  * Mathomatic commands that don't belong anywhere else.
  *
  * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -54,10 +69,10 @@ char	*cp;	/* the command line argument */
 	}
 	if (strchr(cp, 'y')) {
 		printf(_("Performing 3D surface plot...\n"));
-		snprintf(cl, sizeof(cl), "echo 'splot %s'|gnuplot -persist", cp);
+		snprintf(cl, sizeof(cl), "echo 'set grid; splot %s'|gnuplot -persist", cp);
 	} else {
 		printf(_("Performing 2D plot...\n"));
-		snprintf(cl, sizeof(cl), "echo 'plot %s'|gnuplot -persist", cp);
+		snprintf(cl, sizeof(cl), "echo 'set grid; plot %s'|gnuplot -persist", cp);
 	}
 	if (free_cp)
 		free(cp);
@@ -95,6 +110,7 @@ char	*cp;	/* the command line argument */
 
 	fprintf(gfp, _("\nThe newest version of Mathomatic is always available at\n"));
 	fprintf(gfp, _("the Mathomatic website: http://mathomatic.org\n"));
+	fprintf(gfp, _("Feedback and contributions are welcomed.\n"));
 	return rv;
 }
 
@@ -288,7 +304,7 @@ int	product_flag;	/* true for product, otherwise sum */
 	int		i;
 	long		v = 0;			/* Mathomatic variable */
 	double		start, end, step = 1.0;
-	int		result_en;
+	int		result_equation;
 	int		n, ns;
 	token_type	*dest, *source;
 	int		count_down;		/* if true, count down, otherwise count up */
@@ -297,15 +313,15 @@ int	product_flag;	/* true for product, otherwise sum */
 	if (current_not_defined()) {
 		return false;
 	}
-	result_en = next_espace();
+	result_equation = next_espace();
 	if (n_rhs[cur_equation]) {
 		ns = n_rhs[cur_equation];
 		source = rhs[cur_equation];
-		dest = rhs[result_en];
+		dest = rhs[result_equation];
 	} else {
 		ns = n_lhs[cur_equation];
 		source = lhs[cur_equation];
-		dest = lhs[result_en];
+		dest = lhs[result_equation];
 	}
 	if (*cp) {
 		cp = parse_var2(&v, cp);
@@ -378,7 +394,7 @@ int	product_flag;	/* true for product, otherwise sum */
 	if (extra_characters(cp))
 		return false;
 	count_down = (end < start);
-	if (fmod(fabs(start - end) / step, 1.0)) {
+	if (fmod(fabs(start - end) / step, 1.0) != 0.0) {
 		warning(_("End value not reached."));
 	}
 	if (product_flag) {
@@ -418,13 +434,13 @@ int	product_flag;	/* true for product, otherwise sum */
 		calc_simp(dest, &n);
 	}
 	if (n_rhs[cur_equation]) {
-		n_rhs[result_en] = n;
-		blt(lhs[result_en], lhs[cur_equation], n_lhs[cur_equation] * sizeof(token_type));
-		n_lhs[result_en] = n_lhs[cur_equation];
+		n_rhs[result_equation] = n;
+		blt(lhs[result_equation], lhs[cur_equation], n_lhs[cur_equation] * sizeof(token_type));
+		n_lhs[result_equation] = n_lhs[cur_equation];
 	} else {
-		n_lhs[result_en] = n;
+		n_lhs[result_equation] = n;
 	}
-	return return_result(result_en);
+	return return_result(result_equation);
 }
 
 /*
@@ -605,7 +621,7 @@ char	*cp;
 	for (j = i = start; i <= stop; i++) {
 		if (n_lhs[i]) {
 			j = i;
-			simp_sub(i);
+			simp_equation(i);
 		}
 	}
 	stop = j;
@@ -627,9 +643,9 @@ char	*cp;
 			continue;
 		do {
 			flag = false;
-			simp_sub(i);
+			simp_equation(i);
 			for (j = 0; opt_en[j] >= 0; j++) {
-				simp_sub(opt_en[j]);
+				simp_equation(opt_en[j]);
 				if (i != opt_en[j]) {
 					while (find_more(lhs[i], &n_lhs[i], opt_en[j]))
 						flag = true;
@@ -1006,10 +1022,12 @@ try_next_param:
 		quiet_mode = negate;
 		goto try_next_param;
 	}
+#if	false
 	if (strncasecmp(option_string, "html", 4) == 0) {
 		html_flag = !negate;
 		goto try_next_param;
 	}
+#endif
 	if (strncasecmp(option_string, "preserve", 8) == 0) {
 		preserve_surds = !negate;
 		goto try_next_param;
@@ -1275,8 +1293,7 @@ int	imag_flag;	/* if true, copy the imaginary part, otherwise copy the real part
 		}
 	}
 	if (!has_imag || !has_real) {
-		error(_("Failed, expression is not a mix."));
-		return false;
+		warning(_("Expression was not a mix."));
 	}
 	do {
 		simp_loop(dest, &n1);
@@ -1859,7 +1876,7 @@ char	*cp;
 {
 	long		v = 0, v_tmp;		/* Mathomatic variables */
 	int		i, j;
-	int		nleft, nright;
+	int		nleft = 0, nright = 0;
 	double		lcm, d1, d2, d3, d4, d5;
 	complexs	c1, c2, c3;
 
@@ -2140,7 +2157,7 @@ long	v;	/* Mathomatic variable */
 	}
 	subst_var_with_exp(rhs[cur_equation], &n_rhs[cur_equation], rhs[i], n_rhs[i], v);
 	subst_var_with_exp(lhs[cur_equation], &n_lhs[cur_equation], rhs[i], n_rhs[i], v);
-	simp_sub(cur_equation);
+	simp_equation(cur_equation);
 	return true;
 }
 
@@ -2187,6 +2204,7 @@ char	*cp;
 #if     LIBRARY
 				free_result_str();
 				result_str = list_equation(i, false);
+				result_en = i;
 				if (result_str == NULL)
 					return false;
 				if (gfp == stdout) {
@@ -2238,6 +2256,7 @@ char	*cp;
 #if	LIBRARY
 				free_result_str();
 				result_str = list_equation(i, export_flag);
+				result_en = i;
 				if (result_str == NULL)
 					return false;
 				if (gfp == stdout) {
@@ -2470,7 +2489,7 @@ char	*cp;
 				subst_constants(lhs[i], &n_lhs[i]);
 				subst_constants(rhs[i], &n_rhs[i]);
 				approximate_roots = true;
-				simp_sub(i);
+				simp_equation(i);
 				factorv(lhs[i], &n_lhs[i], IMAGINARY);
 				if (n_rhs[i]) {
 					factorv(rhs[i], &n_rhs[i], IMAGINARY);
@@ -2598,7 +2617,7 @@ do_this:
 	blt(lhs[i], tlhs, n_tlhs * sizeof(token_type));
 	n_rhs[i] = n_trhs;
 	blt(rhs[i], trhs, n_trhs * sizeof(token_type));
-	simp_sub(i);
+	simp_equation(i);
 	return return_result(i);
 }
 
@@ -2645,7 +2664,7 @@ char	*cp;
 	for (; i <= j; i++) {
 		if (n_lhs[i]) {
 			if (quickest_flag) {
-				simp_sub(i);
+				simp_equation(i);
 			} else {
 				simpa_repeat_side(lhs[i], &n_lhs[i], quick_flag, frac_flag);
 				simpa_repeat_side(rhs[i], &n_rhs[i], quick_flag, frac_flag);
@@ -2728,7 +2747,7 @@ char	*cp;
 				if (k)
 					fprintf(gfp, ":\n");
 				if (quickest_flag) {
-					simp_sub(i1);
+					simp_equation(i1);
 				} else {
 					simpa_repeat_side(lhs[i1], &n_lhs[i1], quick_flag, frac_flag);
 					simpa_repeat_side(rhs[i1], &n_rhs[i1], quick_flag, frac_flag);
@@ -2765,19 +2784,23 @@ char	*cp;
 	int	i1;
 	int	found;
 	long	v;				/* Mathomatic variable */
+	int	valid_range = false, power_flag = false;
+	char	*cp_start;
+#if	!LIBRARY
+	char	*cp1;
 	double	d;
 	char	buf[MAX_CMD_LEN];
-	int	valid_range = false, power_flag = false;
-	char	*cp1;
+#endif
 
+	cp_start = cp;
+#if	!LIBRARY /* no integer factoring in library mode */
 	if (strcmp_tospace(cp, "number") == 0) {
 		cp = skip_param(cp);
 	} else if (strcmp_tospace(cp, "numbers") == 0) {
-#if	!LIBRARY
 		repeat_flag = true;
-#endif
 		cp = skip_param(cp);
 	} else {
+#endif
 		if (strcmp_tospace(cp, "power") == 0) {
 			power_flag = true;
 			cp = skip_param(cp);
@@ -2793,14 +2816,17 @@ char	*cp;
 				return false;
 #endif
 		}
+#if	!LIBRARY
 	}
 	if (!valid_range) {
 		do {
 			if (*cp == '\0') {
+retry:
 				my_strlcpy(prompt_str, _("Enter integers to factor: "), sizeof(prompt_str));
 				cp = get_string(buf, sizeof(buf));
 				if (cp == NULL)
 					return false;
+				cp_start = cp;
 			}
 			if (*cp == '\0')
 				return true;
@@ -2809,12 +2835,27 @@ char	*cp;
 				d = strtod(cp, &cp);
 				if (cp == cp1) {
 					error(_("Integer expected."));
-					return false;
+					goto retry;
+				}
+				cp = skip_space(cp);
+				if (*cp && !isdigit(*cp)) {
+					input_column += (cp1 - cp_start);
+					cp = parse_expr(tes, &n_tes, cp1);
+					if (cp == NULL)
+						goto retry;
+					if (n_tes <= 0)
+						return true;
+					calc_simp(tes, &n_tes);
+					if (n_tes != 1 || tes[0].kind != CONSTANT) {
+						error(_("Integer expected."));
+						goto retry;
+					}
+					d = tes[0].token.constant;
 				}
 				cp = skip_space(cp);
 				if (!factor_one(d)) {
 					error(_("Number too large to factor or not a non-zero integer."));
-					return false;
+					goto retry;
 				}
 				display_unique();
 				if (is_prime()) {
@@ -2824,6 +2865,7 @@ char	*cp;
 		} while (repeat_flag);
 		return true;
 	}
+#endif
 	if (power_flag) {
 		if (extra_characters(cp))
 			return false;
@@ -3009,17 +3051,24 @@ char	*cp;
 int
 read_cmd(cp)
 char	*cp;
+{
+	if (security_level >= 3) {
+		error(_("Command disabled."));
+		return false;
+	}
+	return read_file(cp);
+}
+
+int
+read_file(cp)
+char	*cp;
 {
 	int	rv;
 	FILE	*fp;
 	char	buf[MAX_CMD_LEN];
 
-	if (security_level >= 3) {
-		error(_("File reading disabled."));
-		return false;
-	}
 	if (*cp == '\0') {
-		error(_("No read file name specified."));
+		error(_("No file name specified."));
 		return false;
 	}
 	snprintf(buf, sizeof(buf), "%s.in", cp);
@@ -3180,7 +3229,7 @@ char	*cp;
 	}
 	clean_up();	/* end any redirection */
 	if (*cp == '\0') {
-		error(_("No save file name specified."));
+		error(_("No file name specified."));
 		return false;
 	}
 #if	!SILENT
