@@ -2,6 +2,21 @@
  * Mathomatic symbolic differentiation routines and related commands.
  *
  * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -289,23 +304,24 @@ int
 derivative_cmd(cp)
 char	*cp;
 {
-	int		i;
+	int		i, len;
 	long		v = 0;		/* Mathomatic variable */
 	long		l1, order = 1;
 	token_type	*source, *dest;
 	int		n1, *nps, *np;
-	int		simplify_flag = true;
+	int		simplify_flag = true, solved;
 
 	if (current_not_defined()) {
 		return false;
 	}
+	solved = solved_equation(cur_equation);
 	if (strcmp_tospace(cp, "nosimplify") == 0) {
 		simplify_flag = false;
 		cp = skip_param(cp);
 	}
 	i = next_espace();
 	if (n_rhs[cur_equation]) {
-		if (!solved_equation(cur_equation)) {
+		if (!solved) {
 			warning(_("Not a solved equation.  Only the RHS will be differentiated."));
 		}
 		source = rhs[cur_equation];
@@ -386,11 +402,19 @@ char	*cp;
 			elim_loop(dest, &n1);
 		}
 	}
+	*np = n1;
 	if (n_rhs[cur_equation]) {
 		blt(lhs[i], lhs[cur_equation], n_lhs[cur_equation] * sizeof(token_type));
 		n_lhs[i] = n_lhs[cur_equation];
+		if (solved && isvarchar('\'')) {
+			len = list_var(lhs[i][0].token.variable, 0);
+			for (l1 = 0; l1 < order && len < (MAX_VAR_LEN - 1); l1++) {
+				var_str[len++] = '\'';
+			}
+			var_str[len] = '\0';
+			parse_var(&lhs[i][0].token.variable, var_str);
+		}
 	}
-	*np = n1;
 	cur_equation = i;
 	return return_result(cur_equation);
 }
