@@ -4,6 +4,21 @@
  * Everything that depends on the command table goes here.
  *
  * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -43,7 +58,7 @@ static com_type com_list[] = {
 {	"edit",		NULL,			edit_cmd,		"[file-name]",						"Edit all equation spaces or an input file, then read them in." },
 #endif
 {	"eliminate",	NULL,			eliminate_cmd,		"variables or \"all\" [\"using\" equation-number]",	"Substitute the specified variables with solved equations.", "This command may be preceded with \"repeat\"." },
-{	"extrema",	NULL,			extrema_cmd,		"[variable] [order]",					"Show where the slope equals zero." },
+{	"extrema",	NULL,			extrema_cmd,		"[variable] [order]",					"Show where the slope of the current equation equals zero." },
 {	"factor",	"collect",		factor_cmd,		"[\"number\" [integers]] or [\"power\"] [equation-number-range] [variables]",	"Factor variables in equation spaces or factor given integers." },
 {	"fraction",	"together",		fraction_cmd,		"[equation-number-range]",				"Convert expression to a single simple fraction, if any fractions are in it." },
 {	"help",		NULL,			help_cmd,		"[topic or command-names]",				"Short, built-in help and reference." },
@@ -103,7 +118,7 @@ char	*example_strings[] = {
 	"variables ; show all variables that occur in an expression\n",
 	"pause\n",
 	"\n",
-	"; Expand into a polynomial:\n",
+	"; Expand the following exponentiated sum into polynomial form:\n",
 	"(x+1)^5\n",
 	"unfactor\n",
 	NULL
@@ -418,7 +433,8 @@ do_repeat:
 
 /*
  * Display and process Mathomatic main prompt input that ends with a newline.
- * Used by the read command.
+ * Used by the read command and "help examples".
+ * The input string will be shortened by set_error_level().
  *
  * Return true if successful.
  */
@@ -586,7 +602,7 @@ next_argument:
 			return true;
 		}
 		if (strncasecmp(cp, "bugs", cp1 - cp) == 0) {
-			P("Report bugs on the Launchpad website:");
+			P("Report bugs on the Launchpad support website for Mathomatic:");
 			P("http://launchpad.net/mathomatic\n");
 
 			P("Please include the following information (from the version command):\n");
@@ -599,7 +615,7 @@ next_argument:
 			for (i = 0, row = 3; i < ARR_CNT(com_list); i++) {
 				fprintf(gfp, "%s %s\n", com_list[i].name, com_list[i].usage);
 				row++;
-				if (gfp == stdout && screen_rows && row >= (screen_rows - 1)) {
+				if (gfp == stdout && screen_rows && row >= (screen_rows - 2)) {
 					row = 1;
 					if (!pause_cmd(""))
 						return false;
@@ -620,8 +636,7 @@ next_argument:
 			P("    area = d*(a + b)/2\n");
 
 			P("Circle of radius \"r\":");
-			P("    area = pi*r^2                 perimeter = 2*pi*r");
-			P("    area = perimeter*r/2\n");
+			P("    area = pi*r^2                 perimeter = 2*pi*r\n");
 
 			P("Rectangular solid of length \"l\", width \"w\", and height \"h\":");
 			P("    volume = l*w*h                surface_area = 2*l*w + 2*l*h + 2*w*h\n");
@@ -645,17 +660,32 @@ next_argument:
 			P("    = equate (lowest precedence)\n");
 
 			P("Variables consist of any combination of letters, digits, and underscores (_).");
-			P("Predefined constants and variables follow:\n");
+			P("Predefined variables follow:\n");
+
+			P("    sign, sign1, sign2, ... - may only be +1 or -1");
+			P("    integer, integer1, ... - may only be an integer value\n");
+
+			P("Absolute value notation \"|x|\" and dual polarity \"+/-x\" are understood.");
+			P("Type \"help constants\" for information on entering constants.");
+			return true;
+		}
+		if (strncasecmp(cp, "constants", cp1 - cp) == 0) {
+			P("Constants are double precision floating point values with up to");
+			P("14 decimal digits accuracy.  They can be entered in standard, scientific,");
+			P("or hexadecimal notation.  Excepting named constants, constants always");
+			P("start with a decimal digit (0..9) or a period.\n");
+
+			P("Named constants follow:\n");
 
 			P("    e or e# - the universal constant e (2.7182818284...)");
 			P("    pi or pi# - the universal constant pi (3.1415926535...)");
 			P("    i or i# - the imaginary unit (square root of -1)");
 			P("The above constants may also be used anywhere variables are required.");
-			P("    sign, sign1, sign2, ... - variables that can only be +1 or -1");
-			P("    integer - variable that can only be an integer value");
-			P("    inf - floating point infinity constant (not a variable)\n");
+			P("    inf - floating point infinity constant");
+			P("    nan - invalid floating point result (not enterable)\n");
 
-			P("Absolute value notation \"|x|\" and dual polarity \"+/-x\" are understood.");
+			fprintf(gfp, "The largest value of a constant is +/-%g\n", DBL_MAX);
+			fprintf(gfp, "The smallest value of a constant is +/-%g\n", DBL_MIN);
 			return true;
 		}
 		if (is_all(cp)) {
@@ -669,7 +699,7 @@ next_argument:
 						return false;
 				}
 			}
-			fprintf(gfp, "End of list; total of %d different commands.\n", ARR_CNT(com_list));
+			fprintf(gfp, "End of command list.  Total of %d different commands.\n", ARR_CNT(com_list));
 			return true;
 		}
 		error(_("Unrecognized help topic or command."));
@@ -677,12 +707,12 @@ next_argument:
 	}
 	/* default help text: */
 	P("Mathomatic is a Computer Algebra System (CAS) and calculator program.");
-	P("To see example expressions and commands, type \"help examples\".");
+	P("To see helpful interactive examples, type \"help examples\".");
 	P("Type \"help equations\" for help with entering expressions and equations.");
 	P("Type \"help all\" for a summary and syntax of all commands.");
 	P("Type \"help usage\" to display the syntax of all commands.");
-	P("Type \"help geometry\" for some commonly used geometric formulas.");
-	P("\"help\" or \"?\" followed by a command name will give info on that command.\n");
+	P("\"help\" or \"?\" followed by a command name will give info on that command.");
+	P("Other help keywords: constants, geometry, copyright, license, bugs.\n");
 
 	fprintf(gfp, "These are the %d commands:\n", ARR_CNT(com_list));
 	for (i = 0; i < ARR_CNT(com_list); i++) {
