@@ -13,10 +13,11 @@
 /*
  * matho_init() - Initialize Mathomatic.
  * Call this only once before calling any Mathomatic code.
- * This must be called exactly once upon program startup and not again.
+ * This must be called exactly once upon program startup and not again,
+ * unless free_mem() is called.
  *
  * Returns true if successful.
- * If this returns false, there was not enough memory
+ * If this returns false, there was not enough memory available
  * and Mathomatic cannot be used.
  */
 int
@@ -34,14 +35,17 @@ matho_init()
 
 /*
  * Process a Mathomatic command or input an expression into an equation space.
- * Input string is in "input", output string is stored in "*outputp".
+ * The input string is in "input", the output string is stored in "*outputp".
  *
  * This function works just like typing something into the Mathomatic prompt.
  *
  * If this returns true (non-zero), the command or input was successful,
- * and the resulting expression output is stored in "*outputp".
+ * and the resulting expression output string is stored in "*outputp".
  * That is a malloc()ed text string which must be free()d after use
  * to return the memory used by the string.
+ * The equation number of the equation space that the output expression
+ * is additionally stored in (if any) is available in the global "result_en",
+ * otherwise result_en = -1.
  *
  * If this returns false, the command or input failed and a text error
  * message is stored in "*outputp".  The error message should NOT be free()d.
@@ -51,7 +55,7 @@ matho_init()
  * except when there is no input.
  */
 int
-matho_process(char *input, const char **outputp)
+matho_process(char *input, char **outputp)
 {
 	int	i;
 	int	rv;
@@ -59,6 +63,7 @@ matho_process(char *input, const char **outputp)
 	if (outputp)
 		*outputp = NULL;
 	result_str = NULL;
+	result_en = -1;
 	error_str = NULL;
 	warning_str = NULL;
 	if (input == NULL)
@@ -71,7 +76,7 @@ matho_process(char *input, const char **outputp)
 		}
 		if (outputp) {
 			if (error_str) {
-				*outputp = error_str;
+				*outputp = (char *) error_str;
 			} else {
 				*outputp = _("Processing was interrupted.");
 			}
@@ -88,7 +93,7 @@ matho_process(char *input, const char **outputp)
 	} else {
 		if (outputp) {
 			if (error_str) {
-				*outputp = error_str;
+				*outputp = (char *) error_str;
 			} else {
 				*outputp = _("Unknown error.");
 			}
@@ -103,7 +108,11 @@ matho_process(char *input, const char **outputp)
  * Parse an equation or expression and store in the next available equation space,
  * making it the current equation.
  *
- * Input string is in "input", output string is stored in "*outputp".
+ * The input and output strings are expressions, if successful.
+ * The input string is in "input", the output string is stored in "*outputp".
+ * The equation number of the equation space that the output expression
+ * is additionally stored in (if any) is available in the global "result_en",
+ * otherwise result_en = -1.
  *
  * Works the same as matho_process() above, except commands are not allowed,
  * so that variables are not confused with commands.
@@ -111,7 +120,7 @@ matho_process(char *input, const char **outputp)
  * Returns true (non-zero) if successful.
  */
 int
-matho_parse(char *input, const char **outputp)
+matho_parse(char *input, char **outputp)
 {
 	int	i;
 	int	rv;
@@ -119,6 +128,7 @@ matho_parse(char *input, const char **outputp)
 	if (outputp)
 		*outputp = NULL;
 	result_str = NULL;
+	result_en = -1;
 	error_str = NULL;
 	warning_str = NULL;
 	if (input == NULL)
@@ -131,7 +141,7 @@ matho_parse(char *input, const char **outputp)
 		}
 		if (outputp) {
 			if (error_str) {
-				*outputp = error_str;
+				*outputp = (char *) error_str;
 			} else {
 				*outputp = _("Processing was interrupted.");
 			}
@@ -153,7 +163,7 @@ matho_parse(char *input, const char **outputp)
 	} else {
 		if (outputp) {
 			if (error_str) {
-				*outputp = error_str;
+				*outputp = (char *) error_str;
 			} else {
 				*outputp = _("Unknown error.");
 			}
