@@ -12,13 +12,13 @@ int
 main(int argc, char **argv)
 {
 	char		*cp;		/* character pointer */
-	const char	*ocp;		/* output character pointer */
+	char		*ocp;		/* output character pointer */
 	int		rv;		/* return value */
 	char		buf[1000];	/* buffer */
 
-	printf("Mathomatic library test program.\n");
+	printf("Mathomatic library test/example program.\n");
 	/* Initialize all global variables and arrays so that Mathomatic will work properly. */
-	if (!matho_init()) {	/* call this function exactly once in your program */
+	if (!matho_init()) {	/* call this library function exactly once in your program */
 		fprintf(stderr, "Not enough memory.\n");
 		exit(1);
 	}
@@ -28,11 +28,21 @@ main(int argc, char **argv)
 		printf("%d-> ", cur_equation + 1);
 		if ((cp = fgets(buf, sizeof(buf), stdin)) == NULL)
 			break;
+		/* Run the Mathomatic symbolic math engine. */
 		rv = matho_process(cp, &ocp);
+		if (warning_str) {
+			/* Optionally display any warnings (not required, but helpful). */
+			printf("Warning: %s\n", warning_str);
+		}
 		if (ocp) {
+			if (rv && result_en >= 0) {
+				/* Display the result equation number. */
+				printf("%d: ", result_en + 1);
+			}
+			/* Display the result. */
 			printf("%s\n", ocp);
 			if (rv) {
-				free((void *) ocp);
+				free(ocp);
 			} else {
 				printf("Error return.\n");
 			}
