@@ -28,7 +28,7 @@ char	*license_string =
 
 "Chief author, maintainer, and copyright holder contact information:\n"
 "  email:\n"
-"    georgegesslein@gmail.com\n"
+"    gesslein@linux.com\n"
 "  postal address:\n"
 "    George Gesslein II\n"
 "    P.O. Box 224\n"
