@@ -3,6 +3,21 @@
  * Color mode routines, too.
  *
  * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -10,7 +25,7 @@
 #define	EQUATE_STRING	" = "	/* string displayed between the LHS and RHS of equations */
 #define MODULUS_STRING	" % "	/* string displayed for the modulus operator */
 
-static int	flist();
+static int	flist_sub();
 static int	flist_recurse();
 
 /* ANSI terminal color code array for 8 color ANSI, we don't use black or white */
@@ -49,7 +64,7 @@ static char	*html_carray[] = {
 	"navy"
 };
 
-/* global variables for flist() below */
+/* global variables for flist_equation() below */
 static int	cur_line;	/* current line */
 static int	cur_pos;	/* current position in the current line on the screen */
 
@@ -76,7 +91,7 @@ reset_attr()
 
 /*
  * Set the current color on the display.
- * Subsequent output will have the color in carray[color].
+ * Subsequent output will have the color in carray[color % ARR_CNT(carray)].
  * Range is 0 to INT_MAX.
  */
 void
@@ -93,12 +108,12 @@ int	color;
 				printf("</font>");
 			}
 			if (bold_colors) {
-				printf("<font color=\"%s\">", bright_html_carray[color%ARR_CNT(bright_html_carray)]);
+				printf("<font color=\"%s\">", bright_html_carray[color % ARR_CNT(bright_html_carray)]);
 			} else {
-				printf("<font color=\"%s\">", html_carray[color%ARR_CNT(html_carray)]);
+				printf("<font color=\"%s\">", html_carray[color % ARR_CNT(html_carray)]);
 			}
 		} else {
-			printf("\033[%d;%dm", bold_colors, carray[color%ARR_CNT(carray)]);
+			printf("\033[%d;%dm", bold_colors, carray[color % ARR_CNT(carray)]);
 		}
 		cur_color = color;
 	}
@@ -137,7 +152,6 @@ char	*buf;
 
 /*
  * Display the expression or equation stored in equation space "n" in single-line format.
- * The equation space is not modified.
  *
  * Return length (number of screen columns) of output line.
  */
@@ -216,6 +230,26 @@ int		n2;
 }
 #endif
 
+/*
+ * Return the allocated string name of the given Mathomatic variable,
+ * or NULL if none.
+ *
+ * Does not return the actual variable name, use list_var() for that.
+ */
+char *
+var_name(v)
+long	v;	/* Mathomatic variable */
+{
+	char	*cp = NULL;
+	long	l;
+
+	l = (v & VAR_MASK) - VAR_OFFSET;
+	if (l >= 0 && l < MAX_VAR_NAMES) {
+		cp = var_names[l];
+	}
+	return cp;
+}
+
 /*
  * Convert the passed Mathomatic variable to an ASCII variable name.
  * The ASCII variable name is stored in the global var_str[].
@@ -225,7 +259,7 @@ int		n2;
  *
  * If (lang_code == 0), use standard Mathomatic format.
  * If (lang_code > 0), make variable compatible with the language defined in the enumeration language_list defined in am.h
- * If (lang_code < 0), create an exportable variable name: -1 for Maxima, -2 for other.
+ * If (lang_code < 0), create an exportable variable name: -1 for Maxima, -2 for other, -3 for Gnuplot.
  */
 int
 list_var(v, lang_code)
@@ -233,6 +267,7 @@ long	v;		/* variable to convert */
 int	lang_code;	/* language code */
 {
 	int		j;
+	int		from_memory = false;
 	char		*cp = NULL;
 
 	var_str[0] = '\0';
@@ -315,10 +350,8 @@ int	lang_code;	/* language code */
 		cp = "all";
 		break;
 	default:
-		j = (v & VAR_MASK) - VAR_OFFSET;
-		if (j >= 0) {
-			cp = var_names[j];
-		}
+		cp = var_name(v);
+		from_memory = true;
 		break;
 	}
 	if (cp) {
@@ -331,13 +364,19 @@ int	lang_code;	/* language code */
 	} else {
 		my_strlcpy(var_str, "bad_variable", sizeof(var_str));
 	}
+	if (from_memory && lang_code) {
+		for (j = 0; var_str[j]; j++) {
+			if (var_str[j] != '_' && !isalnum(var_str[j])) {
+				var_str[j] = '_';
+			}
+		}
+	}
 	return(strlen(var_str));
 }
 
 /*
  * Display an expression in single-line format.
  * Use color if color mode is set.
- * The expression is not modified.
  *
  * Return number of characters output (excluding escape sequences).
  */
@@ -373,7 +412,7 @@ int	export_flag;	/* flag for exportable format (usually false) */
 		len += strlen(EQUATE_STRING);
 		len += list_string(rhs[n], n_rhs[n], NULL, export_flag);
 	}
-	len += 2;
+	len += 2;	/* for possible semicolon and terminating null character */
 	cp = (char *) malloc(len);
 	if (cp == NULL) {
 		error(_("Out of memory (can't malloc(3))."));
@@ -409,7 +448,7 @@ int		export_flag;
 		return NULL;
 	}
 	len = list_string(p1, n, NULL, export_flag);
-	len++;
+	len++;	/* for terminating null character */
 	cp = (char *) malloc(len);
 	if (cp == NULL) {
 		error(_("Out of memory (can't malloc(3))."));
@@ -443,7 +482,8 @@ token_type	*p1;		/* expression pointer */
 int		n;		/* length of expression */
 int		outflag;	/* if true, output to gfp */
 char		*string;	/* buffer to save output to or NULL pointer */
-int		export_flag;
+int		export_flag;	/* flag for exportable format (usually false) */
+				/* 1 for Maxima, 2 for other, 3 for Gnuplot */
 {
 #define	APPEND(str)	{ if (string) { strcpy(&string[len], str); } if (outflag) { fprintf(gfp, "%s", str); } len += strlen(str); }
 
@@ -454,7 +494,9 @@ int		export_flag;
 	int	len = 0;
 	char	buf[500], buf2[500];
 	int	export_precision;
+	int	cflag;		/* color flag */
 
+	cflag = (outflag && !export_flag);
 	if (string)
 		string[0] = '\0';
 	if (high_prec)
@@ -469,11 +511,11 @@ int		export_flag;
 			if (j > 0) {
 				cur_level--;
 				APPEND(")");
-				if (outflag && !export_flag)
+				if (cflag)
 					set_color(cur_level-min1);
 			} else {
 				cur_level++;
-				if (outflag && !export_flag)
+				if (cflag)
 					set_color(cur_level-min1);
 				APPEND("(");
 			}
@@ -550,7 +592,7 @@ int		export_flag;
 	for (j = cur_level - min1; j > 0;) {
 		APPEND(")");
 		j--;
-		if (outflag && !export_flag)
+		if (cflag)
 			set_color(j);
 	}
 	return len;
@@ -570,7 +612,7 @@ int		n;		/* length of expression */
 	for (i = 0; i < n; i++) {
 		switch (p1[i].kind) {
 		case CONSTANT:
-			if (fmod(p1[i].token.constant, 1.0)) {
+			if (fmod(p1[i].token.constant, 1.0) != 0.0) {
 				return false;
 			}
 			break;
@@ -587,7 +629,7 @@ int		n;		/* length of expression */
 }
 
 /*
- * Display an equation as C, Java, or Python code.
+ * Display an equation space as C, Java, or Python code.
  *
  * Return length of output (number of characters).
  */
@@ -620,7 +662,7 @@ int			int_flag;	/* integer arithmetic flag */
 
 /*
  * Output C, Java, or Python code for an expression.
- * Expression might be modified by this function.
+ * Expression might be modified by this function, though it remains equivalent.
  *
  * Return length of output (number of characters).
  */
@@ -691,13 +733,13 @@ int			int_flag;	/* integer arithmetic flag, should work with any language */
 			if (equation[i].token.constant == 0.0) {
 				equation[i].token.constant = 0.0; /* fix -0 */
 			}
-/* note: here we will need to parenthesize negative numbers to make -2**x work the same with Python: */
 			if (int_flag) {
 				snprintf(buf, sizeof(buf), "%.0f", equation[i].token.constant);
 			} else {
 				snprintf(buf, sizeof(buf), "%#.*g", DBL_DIG, equation[i].token.constant);
 				trim_zeros(buf);
 			}
+/* Here we will need to parenthesize negative numbers to make -2**x work the same with Python: */
 			if (equation[i].token.constant < 0) {
 				len += fprintf(gfp, "(%s)", buf);
 			} else {
@@ -757,6 +799,9 @@ int			int_flag;	/* integer arithmetic flag, should work with any language */
  * Display an equation space in 2D multi-line fraction format.
  * Use color if color mode is set.
  *
+ * The equation sides must first be basically simplified and prepared by fractions_and_group(),
+ * for proper display.
+ *
  * Return the total width of the output (that is, the required number of screen columns)
  * or zero on failure.
  */
@@ -765,12 +810,12 @@ flist_equation(n)
 int	n;	/* equation space number */
 {
 	int	sind;
-	char	buf[30];
+	char	buf[50];
 	int	len, len2, len3, width;
 	int	pos;
-	int	high, low;
-	int	max_line, min_line;
-	int	max2_line, min2_line;
+	int	high = 0, low = 0;
+	int	max_line = 0, min_line = 0;
+	int	max2_line = 0, min2_line = 0;
 
 	if (n_lhs[n] <= 0)
 		return 0;
@@ -778,11 +823,11 @@ int	n;	/* equation space number */
 	cur_line = 0;
 	cur_pos = 0;
 	sind = n_rhs[n];
-	len += flist(lhs[n], n_lhs[n], false, 0, &max_line, &min_line);
+	len += flist_sub(lhs[n], n_lhs[n], false, 0, &max_line, &min_line);
 	if (n_rhs[n]) {
 		len += strlen(EQUATE_STRING);
 make_smaller:
-		len2 = flist(rhs[n], sind, false, 0, &high, &low);
+		len2 = flist_sub(rhs[n], sind, false, 0, &high, &low);
 		if (screen_columns && gfp == stdout && (len + len2) >= screen_columns && sind > 0) {
 			for (sind--; sind > 0; sind--) {
 				if (rhs[n][sind].level == 1 && rhs[n][sind].kind == OPERATOR) {
@@ -800,7 +845,7 @@ make_smaller:
 			max_line = high;
 		if (low < min_line)
 			min_line = low;
-		len3 = flist(&rhs[n][sind], n_rhs[n] - sind, false, 0, &max2_line, &min2_line);
+		len3 = flist_sub(&rhs[n][sind], n_rhs[n] - sind, false, 0, &max2_line, &min2_line);
 	} else {
 		len2 = 0;
 		len3 = 0;
@@ -823,13 +868,13 @@ make_smaller:
 			cur_pos += fprintf(gfp, "%s", buf);
 		}
 		pos += strlen(buf);
-		pos += flist(lhs[n], n_lhs[n], true, pos, &high, &low);
+		pos += flist_sub(lhs[n], n_lhs[n], true, pos, &high, &low);
 		if (n_rhs[n]) {
 			if (cur_line == 0) {
 				cur_pos += fprintf(gfp, "%s", EQUATE_STRING);
 			}
 			pos += strlen(EQUATE_STRING);
-			pos += flist(rhs[n], sind, true, pos, &high, &low);
+			pos += flist_sub(rhs[n], sind, true, pos, &high, &low);
 		}
 		fprintf(gfp, "\n");
 	}
@@ -838,7 +883,7 @@ make_smaller:
 		fprintf(gfp, "\n");
 		for (cur_line = max2_line; cur_line >= min2_line; cur_line--) {
 			cur_pos = 0;
-			flist(&rhs[n][sind], n_rhs[n] - sind, true, 0, &high, &low);
+			flist_sub(&rhs[n][sind], n_rhs[n] - sind, true, 0, &high, &low);
 			fprintf(gfp, "\n");
 		}
 	}
@@ -852,10 +897,12 @@ make_smaller:
  * 0 is the middle line, lines above are positive, lines below are negative.
  * Use color if available.
  *
+ * This function is for internal use only, and not to be called, except by flist_equation().
+ *
  * Return the width of the expression (that is, the required number of screen columns).
  */
 static int
-flist(p1, n, out_flag, pos, highp, lowp)
+flist_sub(p1, n, out_flag, pos, highp, lowp)
 token_type	*p1;		/* expression pointer */
 int		n;		/* length of expression */
 int		out_flag;
@@ -1009,7 +1056,11 @@ check_again:
 			if (p1[i].token.constant == 0.0) {
 				p1[i].token.constant = 0.0; /* fix -0 */
 			}
-			if (finance_option) {
+			if (p1[i].token.constant == -1.0 && (i == 0 || p1[i-1].level < p1[i].level)
+			    && (i + 1) < n && p1[i].level == p1[i+1].level && p1[i+1].token.operatr == TIMES) {
+				i++;
+				len += snprintf(buf, sizeof(buf), "-");
+			} else if (finance_option) {
 				if (p1[i].token.constant < 0.0) {
 					len += snprintf(buf, sizeof(buf), "(%.*f)", finance_option, p1[i].token.constant);
 				} else {
