@@ -3,7 +3,24 @@
  * which is a small computer algebra system written entirely in C.
  *
  * Copyright (C) 1987-2010 George Gesslein II.
- *
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
+ */
+
+/*
  * Output to stderr is only done in this file.  The rest of the Mathomatic code
  * should not output to stderr; error messages should use error() or go to stdout.
  *
@@ -52,7 +69,7 @@
 void
 usage()
 {
-	printf(_("\nMathomatic version %s computer algebra system\n\n"), VERSION);
+	printf(_("\nMathomatic computer algebra system version %s\n\n"), VERSION);
 	printf(_("Usage: %s [ options ] [ input_files ]\n\n"), prog_name);
 	printf(_("Options:\n"));
 	printf(_("  -b            Enable bold color mode.\n"));
@@ -67,7 +84,8 @@ usage()
 	printf(_("  -v            Display version information, then exit.\n"));
 	printf(_("  -w            Wide output mode, sets unlimited width.\n"));
 	printf(_("  -x            Enable HTML/XHTML output mode.\n"));
-	printf(_("\nPlease refer to the %s man page for more information.\n"), prog_name);
+	printf(_("\nPlease refer to the Mathomatic man page for more information.\n"));
+	printf(_("The man page is viewed by typing \"man mathomatic\" in shell.\n"));
 }
 
 int
@@ -199,7 +217,7 @@ char	**argv;
 #endif
 		printf("Mathomatic version %s (www.mathomatic.org)\n", VERSION);
 		printf("Copyright (C) 1987-2010 George Gesslein II.\n");
-		printf(_("%d equation spaces available, %ld Kbytes per equation space.\n"),
+		printf(_("%d equation spaces available, %ld kilobytes per equation space.\n"),
 		    N_EQUATIONS, (long) n_tokens * sizeof(token_type) * 2L / 1000L);
 	}
 #if	!SECURE
@@ -256,7 +274,7 @@ char	**argv;
 		for (i = optind; i < argc && argv[i]; i++) {
 			if (strcmp(argv[i], "-") == 0) {
 				main_io_loop();
-			} else if (!read_cmd(argv[i])) {
+			} else if (!read_file(argv[i])) {
 				fprintf(stderr, _("Read of file \"%s\" failed.\n"), argv[i]);
 				exit_program(1);
 			}
@@ -305,6 +323,10 @@ set_signals()
 		rv = false;
 	if (signal(SIGQUIT, inthandler) == SIG_ERR)
 		rv = false;
+	if (signal(SIGTERM, exithandler) == SIG_ERR)
+		rv = false;
+	if (signal(SIGHUP, exithandler) == SIG_ERR)
+		rv = false;
 #if	UNIX || CYGWIN
 	if (signal(SIGWINCH, resizehandler) == SIG_ERR)
 		rv = false;
@@ -411,14 +433,14 @@ int	sig;
 	case 0:
 	case 1:
 		/* wait for graceful abort */
-		printf(_("\nUser interrupt signal received; Three times quits.\n"));
+		printf(_("\nUser interrupt signal received; three times quits Mathomatic.\n"));
 		return;
 	case 2:
 		printf(_("\nPress Control-C once more to quit program.\n"));
 		return;
 	default:
 		/* abruptly quit this program */
-		printf(_("\nRepeatedly interrupted; Quitting...\n"));
+		printf(_("\nRepeatedly interrupted; returning to operating system...\n"));
 		exit_program(1);
 	}
 }
@@ -434,6 +456,16 @@ int	sig;
 	exit_program(1);
 }
 
+/*
+ * Signal handler for proper exiting to the operating system.
+ */
+void
+exithandler(sig)
+int	sig;
+{
+	exit_program(1);
+}
+
 #if	UNIX || CYGWIN
 /*
  * Window resize signal handler.
