@@ -2,6 +2,21 @@
  * Expression parsing routines for Mathomatic.
  *
  * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -426,7 +441,7 @@ parse_power:
 				}
 			}
 			if (*cp == '(') {
-				put_up_arrow(cp1 - cp_start, _("Named functions currently not implemented."));
+				put_up_arrow(cp1 - cp_start, _("Named functions currently not implemented, except when using m4."));
 				return(NULL);
 			}
 			cp--;
@@ -567,7 +582,7 @@ char	*cp;
 	int	len;
 	int	(*strcmpfunc)();
 
-	*vp = V_NULL;
+/*	*vp = V_NULL; */
 	if (case_sensitive_flag) {
 		strcmpfunc = strcmp;
 	} else {
