@@ -19,6 +19,21 @@
  * Maximum simplification of all expressions is not possible unless everything is generalized.
  *
  * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -714,7 +729,34 @@ long		v;
 }
 
 /*
- * Return true if passed expression is entirely integer and any variables
+ * This function returns true if the passed Mathomatic variable
+ * is of type integer.
+ *
+ * Integer variable names start with "integer".
+ */
+int
+is_integer_var(v)
+long	v;
+{
+	char	*cp;
+	int	(*strncmpfunc)();
+
+	if (case_sensitive_flag) {
+		strncmpfunc = strncmp;
+	} else {
+		strncmpfunc = strncasecmp;
+	}
+
+	cp = var_name(v);
+	if (cp && strncmpfunc(cp, V_INTEGER_PREFIX, strlen(V_INTEGER_PREFIX)) == 0)
+		return true;
+	else
+		return false;
+}
+
+/*
+ * This function is a strict test that
+ * returns true if passed expression is entirely integer and all variables
  * are either "integer" or "sign".
  *
  * The result of evaluating the expression must be integer if this returns true.
@@ -726,9 +768,7 @@ token_type	*p1;	/* expression pointer */
 int		n;	/* length of expression */
 {
 	int	i;
-	long	v_integer;
 
-	parse_var(&v_integer, V_INTEGER_NAME);
 	for (i = 0; i < n; i++) {
 		switch (p1[i].kind) {
 		case OPERATOR:
@@ -736,11 +776,12 @@ int		n;	/* length of expression */
 				return false;
 			break;
 		case CONSTANT:
-			if (fmod(p1[i].token.constant, 1.0))
+			if (fmod(p1[i].token.constant, 1.0) != 0.0)
 				return false;
 			break;
 		case VARIABLE:
-			if (p1[i].token.variable != v_integer && (p1[i].token.variable & VAR_MASK) != SIGN)
+			if (!is_integer_var(p1[i].token.variable)
+			    && (p1[i].token.variable & VAR_MASK) != SIGN)
 				return false;
 			break;
 		}
@@ -749,7 +790,7 @@ int		n;	/* length of expression */
 }
 
 /*
- * This routine is a modulus (%) simplifier for equation sides.
+ * This routine is a modulus operator (%) simplifier for equation sides.
  *
  * Return true if expression was modified.
  */
@@ -1895,6 +1936,7 @@ int		*dcodep;	/* divide flag pointer indicates if term is a denominator */
 	int		rv;
 	int		count = 0;
 
+	CLEAR_ARRAY(last_va);
 	*pp1 = 0.0;
 	*tp1 = -1;
 	rv = *dcodep;
