@@ -2,6 +2,21 @@
  * Mathomatic simplifying routines.
  *
  * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -212,7 +227,7 @@ int		fc_level;	/* factor constants code, passed to factor_constants() */
  * No factoring is done.
  */
 void
-simp_sub(n)
+simp_equation(n)
 int	n;	/* equation space number to simplify */
 {
 	if (n_lhs[n] <= 0)
