@@ -2,6 +2,21 @@
  * Mathomatic symbolic solve routines.
  *
  * Copyright (C) 1987-2010 George Gesslein II.
+ 
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public 
+    License as published by the Free Software Foundation; either 
+    version 2.1 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of 
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
+ 
+    You should have received a copy of the GNU Lesser General Public 
+    License along with this library; if not, write to the Free Software 
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ 
  */
 
 #include "includes.h"
@@ -1173,8 +1188,9 @@ int		*side2np;	/* pointer to the length of "side2p" */
 		p2++;
 		p2->level = 2;
 		p2->kind = VARIABLE;
-		snprintf(var_name_buf, sizeof(var_name_buf), "%s%.0d", V_INTEGER_NAME, last_int_var);
-		parse_var(&p2->token.variable, var_name_buf);
+		snprintf(var_name_buf, sizeof(var_name_buf), "%s%.0d", V_INTEGER_PREFIX, last_int_var);
+		if (parse_var(&p2->token.variable, var_name_buf) == NULL)
+			return false;
 		last_int_var++;
 		if (last_int_var < 0) {
 			last_int_var = 0;
